@@ -11,9 +11,8 @@ class Asciicast(object):
         self.shell = env['SHELL']
         self.term = env['TERM']
         self.username = env['USER']
-        unametemp = os.uname()
-        self.uname = "%s %s %s %s" % (unametemp[0], unametemp[2], unametemp[3], unametemp[4])
 
+    @property
     def meta_data(self):
         lines = int(get_command_output(['tput', 'lines']))
         columns = int(get_command_output(['tput', 'cols']))
@@ -24,7 +23,6 @@ class Asciicast(object):
             'title'      : self.title,
             'command'    : self.command,
             'shell'      : self.shell,
-            'uname'      : self.uname,
             'term'       : {
                 'type'   : self.term,
                 'lines'  : lines,
